@@ -48,29 +48,21 @@
 #include "statcodes.h"
 #include "sock.h"
 #include "UpnpInet.h"
+#include "UpnpIntTypes.h"
+#include "UpnpStdInt.h"
 #include "webserver.h"
 
 #include <assert.h>
 #include <stdarg.h>
 
-#ifndef UPNP_USE_BCBPP
-	#ifndef UPNP_USE_MSVCPP
-		#include <inttypes.h>
-		#include <stdint.h>
-	#endif
-#endif
-
 #ifdef WIN32
 	#include <malloc.h>
 	#define fseeko fseek
 #else
 	#include <arpa/inet.h>
-	#include <fcntl.h>
 	#include <sys/types.h>
-	#include <sys/socket.h>
 	#include <sys/time.h>
 	#include <sys/wait.h>
-	#include <unistd.h>
 	#include <sys/utsname.h>
 #endif
 
@@ -90,78 +82,17 @@ const int CHUNK_TAIL_SIZE = 10;
 /* in seconds */
 #define DEFAULT_TCP_CONNECT_TIMEOUT 5
 
-/************************************************************************
- * Function : Make_Socket_NoBlocking
+/*!
+ * \brief Checks socket connection and wait if it is not connected.
+ * It should be called just after connect.
  *
- * Parameters:
- *	IN int sock: socket
- *
- * Description:
- *	This function makes socket non-blocking.
- *
- * Returns: int
- *	0 if successful else -1 
- ***************************************************************************/
-static int Make_Socket_NoBlocking(SOCKET sock)
-{
-#ifdef WIN32
-	u_long val = 1;
-	return ioctlsocket(sock, FIONBIO, &val);
-#else
-	int val;
-
-	val = fcntl(sock, F_GETFL, 0);
-	if (fcntl(sock, F_SETFL, val | O_NONBLOCK) == -1) {
-		return -1;
-	}
-#endif
-	return 0;
-}
-
-/************************************************************************
- * Function : Make_Socket_Blocking
- *
- * Parameters:
- *	IN int sock: socket
- *
- * Description:
- *	This function makes socket blocking.
- *
- * Returns: int
- *	0 if successful else -1 
- ***************************************************************************/
-static int Make_Socket_Blocking(int sock)
-{
-#ifdef WIN32
-	u_long val = 0;
-	return ioctlsocket(sock, FIONBIO, &val);
-#else
-	int val;
-
-	val = fcntl(sock, F_GETFL, 0);
-	if (fcntl(sock, F_SETFL, val & ~O_NONBLOCK) == -1) {
-		return -1;
-	}
-#endif
-	return 0;
-}
-
-
-/************************************************************************
- * Function : Check_Connect_And_Wait_Connection
- *
- * Parameters:
- *	IN int sock: socket
- *  IN int connect_res: result of connect
- *
- * Description:
- *	This function checks socket connection and wait if it is not connected
- *  It should be called just after connect
- *
- * Returns: int
- *	0 if successful else -1 
- ***************************************************************************/
-static int Check_Connect_And_Wait_Connection(int sock, int connect_res)
+ * \return 0 if successful, else -1.
+ */
+static int Check_Connect_And_Wait_Connection(
+	/*! [in] socket. */
+	SOCKET sock,
+	/*! [in] result of connect. */
+	int connect_res)
 {
 	struct timeval tmvTimeout = {DEFAULT_TCP_CONNECT_TIMEOUT, 0};
 	int result;
@@ -216,12 +147,12 @@ static int private_connect(
 	socklen_t addrlen)
 {
 #ifndef UPNP_ENABLE_BLOCKING_TCP_CONNECTIONS
-	int ret = Make_Socket_NoBlocking(sockfd);
+	int ret = sock_make_no_blocking(sockfd);
 	if (ret != - 1) {
 		ret = connect(sockfd, serv_addr, addrlen);
 		ret = Check_Connect_And_Wait_Connection(sockfd, ret);
 		if (ret != - 1) {
-			ret = Make_Socket_Blocking(sockfd);
+			ret = sock_make_blocking(sockfd);
 		}
 	}
 
@@ -515,7 +446,7 @@ int http_SendMessage(SOCKINFO *info, int *TimeOut, const char *fmt, ...)
 					/* Copy CRLF at the end of the chunk */
 					memcpy(file_buf + num_read, "\r\n", 2);
 					/* Hex length for the chunk size. */
-					sprintf(Chunk_Header, "%zx", num_read);
+					sprintf(Chunk_Header, "%" PRIzx, num_read);
 					/*itoa(num_read,Chunk_Header,16);  */
 					strcat(Chunk_Header, "\r\n");
 					/* Copy the chunk size header  */
@@ -919,7 +850,7 @@ int http_WriteHttpPost( IN void *Handle,
 			if (!tempbuf)
 				return UPNP_E_OUTOF_MEMORY;
 			/* begin chunk */
-			sprintf(tempbuf, "%zx\r\n", *size);
+			sprintf(tempbuf, "%" PRIzx "\r\n", *size);
 			tempSize = strlen(tempbuf);
 			memcpy(tempbuf + tempSize, buf, *size);
 			memcpy(tempbuf + tempSize + *size, "\r\n", 2);
@@ -1311,8 +1242,8 @@ int http_ReadHttpGet(
 		return UPNP_E_BAD_RESPONSE;
 	}
 	/* read more if necessary entity */
-	while (handle->response.msg.entity_offset + *size >
-		handle->response.msg.entity.length &&
+	while (handle->response.msg.amount_discarded + *size >
+	       handle->response.msg.entity.length &&
 	       !handle->cancel &&
 	       handle->response.position != POS_COMPLETE) {
 		num_read = sock_read(&handle->sock_info, tempbuf,
@@ -1356,20 +1287,25 @@ int http_ReadHttpGet(
 			return num_read;
 		}
 	}
-	if (handle->response.msg.entity_offset + *size >
-	    handle->response.msg.entity.length)
-		*size = handle->response.msg.entity.length -
-		    handle->response.msg.entity_offset;
-	memcpy(buf, &handle->response.msg.msg.buf[handle->response.entity_start_position],
-		*size);
-	/* FIXME: testing size AFTER memcopy? Weird... */
-	if (*size > 0)
-		membuffer_delete(&handle->response.msg.msg,
-			handle->response.entity_start_position, *size);
-	handle->response.msg.entity_offset += *size;
 	if (handle->cancel) {
 		return UPNP_E_CANCELED;
 	}
+	/* truncate size to fall within available data */
+	if (handle->response.msg.amount_discarded + *size >
+	    handle->response.msg.entity.length)
+		*size = handle->response.msg.entity.length -
+			handle->response.msg.amount_discarded;
+	/* copy data to user buffer. delete copied data */
+	if (*size > 0) {
+		memcpy(buf, &handle->response.msg.msg.buf[handle->response.entity_start_position],
+			*size);
+		membuffer_delete(&handle->response.msg.msg,
+			handle->response.entity_start_position, *size);
+		/* update scanner position. needed for chunked transfers */
+		handle->response.scanner.cursor -= *size;
+		/* update amount discarded */
+		handle->response.msg.amount_discarded += *size;
+	}
 
 	return UPNP_E_SUCCESS;
 }
@@ -1638,7 +1574,7 @@ int http_MakeMessage(membuffer *buf, int http_major_version,
 	const char *temp_str;
 	uri_type url;
 	uri_type *uri_ptr;
-	int error_code = UPNP_E_OUTOF_MEMORY;
+	int error_code = 0;
 	va_list argp;
 	char tempbuf[200];
 	const char *weekday_str = "Sun\0Mon\0Tue\0Wed\0Thu\0Fri\0Sat";
@@ -1702,14 +1638,14 @@ int http_MakeMessage(membuffer *buf, int http_major_version,
 				start_str = "DATE: ";
 				end_str = "\r\n";
 				curr_time = time(NULL);
-				date = gmtime(&curr_time);
+				loc_time = &curr_time;
 			} else {
 				/* date value only */
 				start_str = end_str = "";
 				loc_time = (time_t *)va_arg(argp, time_t *);
-				assert(loc_time);
-				date = gmtime(loc_time);
 			}
+			assert(loc_time);
+			date = gmtime(loc_time);
 			sprintf(tempbuf,
 				"%s%s, %02d %s %d %02d:%02d:%02d GMT%s",
 				start_str, &weekday_str[date->tm_wday * 4],
@@ -1827,12 +1763,16 @@ int http_MakeMessage(membuffer *buf, int http_major_version,
 			assert(0);
 		}
 	}
+	goto ExitFunction;
 
-	return 0;
-
- error_handler:
-	va_end(argp);
+error_handler:
+	/* Default is out of memory error. */
+	if (!error_code)
+		error_code = UPNP_E_OUTOF_MEMORY;
 	membuffer_destroy(buf);
+
+ExitFunction:
+	va_end(argp);
 	return error_code;
 }
 
